# Cosine Utils

This package provides a utility to compute cosine similarity between vectors as a percentage. It's implemented using Cython for better performance.

## Installation

You can install it via pip:

```bash
pip install cosine_utils

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
